import logging
import uuid

import constance
from django.db import models

from core.models.submission import Submission

log = logging.getLogger(__name__)
config = constance.config


class DeletionOfDoneAssignmentsNotPermitted(Exception):
    pass


class TutorSubmissionAssignment(models.Model):

    assignment_id = models.UUIDField(primary_key=True,
                                     default=uuid.uuid4,
                                     editable=False)
    submission = models.ForeignKey(Submission,
                                   on_delete=models.CASCADE,
                                   related_name='assignments')
    subscription = models.ForeignKey('SubmissionSubscription',
                                     on_delete=models.CASCADE,
                                     related_name='assignments')
    is_done = models.BooleanField(default=False)
    created = models.DateTimeField(auto_now_add=True)

    def __str__(self):
        return (f'{self.subscription.owner} assigned to {self.submission}'
                f' (done={self.is_done})')

    def delete(self, *args, **kwargs):
        if self.is_done:
            raise DeletionOfDoneAssignmentsNotPermitted()
        super().delete(*args, **kwargs)

    class Meta:
        unique_together = ('submission', 'subscription')
